# PREAMBLE ----
# File: nomikos_pshare_replication.R
# Description: Replication for Why Share? 
# Author: William G. Nomikos
# Last Update: 9/29/20

# Presets
rm(list=ls())
setwd("/Users/williamnomikos/Dropbox/Work/Projects/Power-Sharing/Final Submission/Replication") #Set to your Working Directory
getwd()

# **Libraries ----

library(readxl)
library(haven)
library(countrycode)
library(tidyverse)
library(xtable)
library(knitr)
library(kableExtra)
library(multiwayvcov)
library(sandwich)
library(lmtest)
library(stargazer)
library(konfound)

# IMPORT DATA

#** Nomikos data ----
nomikos_pshare<-as_tibble(read_csv("nomikos_pshare.csv")) %>%
  print()

# **No majority data subset ----
nomikos_pshare_nomaj<-filter(nomikos_pshare,maj_grp==0)


# TABLES ----

# ** Table II ----

# Top Half of Table
table(nomikos_pshare$pshare, nomikos_pshare$maj_grp) # Rows 1-2
table(nomikos_pshare$pshare) # Row 3
table(nomikos_pshare$maj_grp) # Column 4

# Bottom Half of Table
table(nomikos_pshare_nomaj$pshare, nomikos_pshare_nomaj$maj_unified) # Rows 1-2
table(nomikos_pshare_nomaj$pshare) # Row 3
table(nomikos_pshare_nomaj$maj_unified) # Column 4


# ** Table III----
reg <- glm(pshare_inst ~ maj_grp+unintrvn+ELF+gdp_grow+stalemate+dem_age, family=binomial(link="logit"), data=nomikos_pshare)
summary(reg)
n1<-nobs(reg)
vcov <- cluster.vcov(reg, nomikos_pshare$cluster)
logit1<-coeftest(reg, vcov)
logit1

reg <- glm(pshare_inst ~ group1+unintrvn+ELF+gdp_grow+stalemate+dem_age, family=binomial(link="logit"), data=nomikos_pshare)
summary(reg)
n2<-nobs(reg)
vcov <- cluster.vcov(reg, nomikos_pshare$cluster)
logit2<-coeftest(reg, vcov)
logit2


reg <- glm(pshare_inst ~ maj_unified+unintrvn+ELF+gdp_grow+stalemate+dem_age, family=binomial(link="logit"), data=nomikos_pshare)
summary(reg)
n3<-nobs(reg)
vcov <- cluster.vcov(reg, nomikos_pshare$cluster)
logit3<-coeftest(reg, vcov)
logit3

reg <- glm(pshare_inst ~ unintrvn+ELF+gdp_grow+stalemate+dem_age, family=binomial(link="logit"), data=nomikos_pshare)
summary(reg)
n4<-nobs(reg)
vcov <- cluster.vcov(reg, nomikos_pshare$cluster)
logit4<-coeftest(reg, vcov)
logit4


reg <- glm(pshare_inst ~ strongun+weakun+ELF+gdp_grow+stalemate+dem_age, family=binomial(link="logit"), data=nomikos_pshare)
summary(reg)
n5<-nobs(reg)
vcov <- cluster.vcov(reg, nomikos_pshare$cluster)
logit5<-coeftest(reg, vcov)
logit5


stargazer(logit1,logit2,logit3,logit4,logit5,
          title="Logit regression results. Robust, country-year-clustered standard errors.",
          add.lines=list(c(""),c("Observations", n1,n2,n3,n4,n5)),
          align=TRUE, style="APSR", out="Tables/tab_logits.tex", 
          keep=c("maj_grp","group1","maj_unified","unintrvn","strongun","weakun","ELF", "gdp_grow","stalemate","dem_age"),
          covariate.labels = c("Majority Present","Largest Group Size","Majority Unified","UNPKO","Strong PKO","Weak PKO","ELF", "GDP Growth","Stalemate","Democracy Age"),
          #column.labels=c("no controls","FEs","controls","FEs and controls"),
          model.numbers=T,
          label="tab_logits",
          table.placement = "h!",
          no.space=T,
          font.size="footnotesize",
          star.cutoffs = c(0.05,0.01,0.001)
)

# ** Table IV----

# Sensitivity Analysis 

# ** Maj Grp 
reg <- lm(pshare_inst ~ maj_grp+unintrvn+ELF+gdp_grow+stalemate+dem_age, data=nomikos_pshare)
summary(reg)
konfound(reg,maj_grp)

# Compare Impact to ELF
impact_elf<-abs(cor(nomikos_pshare$maj_grp,nomikos_pshare$ELF)*cor(nomikos_pshare$pshare_inst,nomikos_pshare$ELF))
impact_elf

# Compare Impact to gdp_grow
impact_gdp<-abs(cor(nomikos_pshare$maj_grp,nomikos_pshare$gdp_grow)*cor(nomikos_pshare$pshare_inst,nomikos_pshare$gdp_grow))
impact_gdp

# Compare Impact to stalemate
impact_stalemate<-abs(cor(nomikos_pshare$maj_grp,nomikos_pshare$stalemate)*cor(nomikos_pshare$pshare_inst,nomikos_pshare$stalemate))
impact_stalemate


# Compare Impact to dem age
impact_demage<-abs(cor(nomikos_pshare$maj_grp,nomikos_pshare$dem_age)*cor(nomikos_pshare$pshare_inst,nomikos_pshare$dem_age))
impact_demage


# ** group 1 size
reg <- lm(pshare_inst ~ group1+unintrvn+ELF+gdp_grow+stalemate+dem_age, data=nomikos_pshare)
summary(reg)
konfound(reg,group1)

# Compare Impact to ELF
impact_elf<-abs(cor(nomikos_pshare$group1,nomikos_pshare$ELF)*cor(nomikos_pshare$pshare_inst,nomikos_pshare$ELF))
impact_elf


# Compare Impact to gdp_grow
impact_gdp<-abs(cor(nomikos_pshare$group1,nomikos_pshare$gdp_grow)*cor(nomikos_pshare$pshare_inst,nomikos_pshare$gdp_grow))
impact_gdp


# Compare Impact to stalemate
impact_stalemate<-abs(cor(nomikos_pshare$group1,nomikos_pshare$stalemate)*cor(nomikos_pshare$pshare_inst,nomikos_pshare$stalemate))
impact_stalemate


# Compare Impact to dem age
impact_demage<-abs(cor(nomikos_pshare$group1,nomikos_pshare$dem_age)*cor(nomikos_pshare$pshare_inst,nomikos_pshare$dem_age))
impact_demage


# ** maj unified
reg <- lm(pshare_inst ~ maj_unified+unintrvn+ELF+gdp_grow+stalemate+dem_age, data=nomikos_pshare)
summary(reg)
konfound(reg,maj_unified)

# Compare Impact to ELF
impact_elf<-abs(cor(nomikos_pshare$maj_unified,nomikos_pshare$ELF)*cor(nomikos_pshare$pshare_inst,nomikos_pshare$ELF))
impact_elf

# Compare Impact to gdp_grow
impact_gdp<-abs(cor(nomikos_pshare$maj_unified,nomikos_pshare$gdp_grow)*cor(nomikos_pshare$pshare_inst,nomikos_pshare$gdp_grow))
impact_gdp


# Compare Impact to stalemate
impact_stalemate<-abs(cor(nomikos_pshare$maj_unified,nomikos_pshare$stalemate)*cor(nomikos_pshare$pshare_inst,nomikos_pshare$stalemate))
impact_stalemate


# Compare Impact to dem age
impact_demage<-abs(cor(nomikos_pshare$maj_unified,nomikos_pshare$dem_age)*cor(nomikos_pshare$pshare_inst,nomikos_pshare$dem_age))
impact_demage



# ** unintrvn
reg <- lm(pshare_inst ~ unintrvn+ELF+gdp_grow+stalemate+dem_age, data=nomikos_pshare)
summary(reg)
konfound(reg,unintrvn)

# Compare Impact to ELF
impact_elf<-abs(cor(nomikos_pshare$unintrvn,nomikos_pshare$ELF)*cor(nomikos_pshare$pshare_inst,nomikos_pshare$ELF))
impact_elf

# Compare Impact to gdp_grow
impact_gdp<-abs(cor(nomikos_pshare$unintrvn,nomikos_pshare$gdp_grow)*cor(nomikos_pshare$pshare_inst,nomikos_pshare$gdp_grow))
impact_gdp

# Compare Impact to stalemate
impact_stalemate<-abs(cor(nomikos_pshare$unintrvn,nomikos_pshare$stalemate)*cor(nomikos_pshare$pshare_inst,nomikos_pshare$stalemate))
impact_stalemate


# Compare Impact to dem age
impact_demage<-abs(cor(nomikos_pshare$unintrvn,nomikos_pshare$dem_age)*cor(nomikos_pshare$pshare_inst,nomikos_pshare$dem_age))
impact_demage


# FIGURES ----
# **Figure 1 ----
model <- glm(pshare_inst ~ maj_grp+unintrvn+ELF+gdp_grow+stalemate+dem_age, family=binomial(link="logit"), data=nomikos_pshare)

# Create a temporary data frame of hypothetical values
temp.data <- data.frame(maj_grp = rep(seq(0, 1, 1), 1),
                        unintrvn = c(0,0,1,1),
                        ELF=mean(nomikos_pshare$ELF,na.rm=T),
                        gdp_grow=mean(nomikos_pshare$gdp_grow,na.rm=T),
                        stalemate=median(nomikos_pshare$stalemate,na.rm=T),
                        dem_age=mean(nomikos_pshare$dem_age)
)

# Predict the fitted values given the model and hypothetical data
predicted.data <- as.data.frame(predict(model, newdata = temp.data, 
                                        type="link", se=TRUE))

# Combine the hypothetical data and predicted values
new.data <- cbind(temp.data, predicted.data)

# Calculate confidence intervals
std <- qnorm(0.95 / 2 + 0.5)
new.data$ymin <- model$family$linkinv(new.data$fit - std * new.data$se)
new.data$ymax <- model$family$linkinv(new.data$fit + std * new.data$se)
new.data$fit <- model$family$linkinv(new.data$fit)  # Rescale to 0-1
names<-c("No majority (No PKO)","Majority (No PKO)","No majority (PKO)","Majority (PKO)")
new.data$group<-factor(names,levels=names)
# Plot everything


ggplot(aes(x=group, y=fit,ymin=ymin, ymax=ymax, color=group),data=new.data)+
  geom_linerange(size=1)+
  scale_color_manual(values=c("#FF3300", "#FF3300", "#3399FF","#3399FF"))+
  geom_point(size=12,shape=21, fill="white")+
  geom_text(x=c(1,2,3,4), y=new.data$fit, label=round(new.data$fit,2))+
  labs(x="", y="Pr(Institutional power-sharing)")+
  theme_bw()+
  theme(legend.position="none", 
        axis.text.x =  element_text(size=10, face="bold",margin = margin(t = 10, r = 0, b = 0, l = 0)),
        axis.title.y = element_text(size=15,margin = margin(t = 0, r = 20, b = 0, l = 20)))

ggsave("Figures/fig_maj_grp.jpg", height=6, width=10)


#**Figure 2----


# Run logistic regression model
model <- glm(pshare_inst ~ group1+unintrvn+ELF+gdp_grow+stalemate+dem_age, family=binomial(link="logit"), data=nomikos_pshare)
summary(model)

# Create a temporary data frame of hypothetical values
temp.data <- data.frame(group1 = rep(seq(0.005, 1, 0.005), 1),
                        unintrvn =  c(rep(0, 200),rep(1,200)),
                        ELF=mean(nomikos_pshare$ELF,na.rm=T),
                        gdp_grow=mean(nomikos_pshare$gdp_grow,na.rm=T),
                        stalemate=median(nomikos_pshare$stalemate,na.rm=T),
                        dem_age=mean(nomikos_pshare$dem_age)
)

# Predict the fitted values given the model and hypothetical data
predicted.data <- as.data.frame(predict(model, newdata = temp.data, 
                                        type="link", se=TRUE))

# Combine the hypothetical data and predicted values
new.data <- cbind(temp.data, predicted.data)

# Calculate confidence intervals
std <- qnorm(0.95 / 2 + 0.5)
new.data$ymin <- model$family$linkinv(new.data$fit - std * new.data$se)
new.data$ymax <- model$family$linkinv(new.data$fit + std * new.data$se)
new.data$fit <- model$family$linkinv(new.data$fit)  # Rescale to 0-1

new.data$UN<-ifelse(new.data$unintrvn==0,"No PKO","PKO")

# Plot everything
p <- ggplot(nomikos_pshare, aes(x=group1, y=pshare_inst)) 
p + geom_ribbon(data=new.data, aes(y=fit, ymin=ymin, ymax=ymax,fill=UN), alpha=0.5) + 
  geom_line(data=new.data, aes(y=fit,fill=UN)) + 
  theme(axis.title.y=element_text(margin=margin(0,20,0,0)))+
  theme(axis.title.x=element_text(margin=margin(20,0,0,0)))+
  #ggtitle("Institutional Power-Sharing Probability as Function of Group Size (no UN)")+
  labs(x="Size of largest group", y="Pr(Institutional power-sharing)")

#Save
ggsave("Figures/fig_grp1.jpg", height=6, width=10)





# **Figure 3  ----


# Run logistic regression model
model <- glm(pshare_inst ~ maj_unified+unintrvn+ELF+gdp_grow+stalemate+dem_age, family=binomial(link="logit"), data=nomikos_pshare)
summary(model)

# Create a temporary data frame of hypothetical values
temp.data <- data.frame(maj_unified = rep(seq(0, 1, 1), 1),
                        unintrvn = c(0,0,1,1),
                        ELF=mean(nomikos_pshare$ELF,na.rm=T),
                        gdp_grow=mean(nomikos_pshare$gdp_grow,na.rm=T),
                        stalemate=median(nomikos_pshare$stalemate,na.rm=T),
                        dem_age=mean(nomikos_pshare$dem_age)
)

# Predict the fitted values given the model and hypothetical data
predicted.data <- as.data.frame(predict(model, newdata = temp.data, 
                                        type="link", se=TRUE))

# Combine the hypothetical data and predicted values
new.data <- cbind(temp.data, predicted.data)

# Calculate confidence intervals
std <- qnorm(0.95 / 2 + 0.5)
new.data$ymin <- model$family$linkinv(new.data$fit - std * new.data$se)
new.data$ymax <- model$family$linkinv(new.data$fit + std * new.data$se)
new.data$fit <- model$family$linkinv(new.data$fit)  # Rescale to 0-1
names<-c("Majority not unified (No PKO)","Majority unified (No PKO)","Majority not unified (PKO)","Majority unified (PKO)")
new.data$group<-factor(names,levels=names)
# Plot everything


ggplot(aes(x=group, y=fit,ymin=ymin, ymax=ymax, color=group),data=new.data)+
  geom_linerange(size=1)+
  scale_color_manual(values=c("#FF3300", "#FF3300", "#3399FF","#3399FF"))+
  geom_point(size=12,shape=21, fill="white")+
  geom_text(x=c(1,2,3,4), y=new.data$fit, label=round(new.data$fit,2))+
  labs(x="", y="Pr(Institutional power-sharing)")+
  theme_bw()+
  theme(legend.position="none", 
        axis.text.x =  element_text(size=8, face="bold",margin = margin(t = 10, r = 0, b = 0, l = 0)),
        axis.title.y = element_text(size=15,margin = margin(t = 0, r = 20, b = 0, l = 20)))

ggsave("Figures/fig_majunified.jpg", height=6, width=10)


